@@ -107,7 +107,7 @@ class NXOntology(Freezable, Generic[Node]):
             raise DuplicateError(f"edge already in graph: {u_of_edge} --> {v_of_edge}")
         self.graph.add_edge(u_of_edge, v_of_edge, **attr)
 
-    @property  # type: ignore [misc]
+    @property
     @cache_on_frozen
     def roots(self) -> set[Node]:
         """
@@ -133,7 +133,7 @@ class NXOntology(Freezable, Generic[Node]):
             return root
         raise ValueError("Ontology has multiple roots.")
 
-    @property  # type: ignore [misc]
+    @property
     @cache_on_frozen
     def leaves(self) -> set[Node]:
         """
@@ -145,7 +145,7 @@ class NXOntology(Freezable, Generic[Node]):
                 leaves.add(node)
         return leaves
 
-    @property  # type: ignore [misc]
+    @property
     @cache_on_frozen
     def isolates(self) -> set[Node]:
         """
@@ -192,7 +192,7 @@ class NXOntology(Freezable, Generic[Node]):
         self,
         source_nodes: Iterable[Node],
         target_nodes: Iterable[Node],
-        ic_metrics: list[str] = ["intrinsic_ic_sanchez"],
+        ic_metrics: list[str] | tuple[str, ...] = ("intrinsic_ic_sanchez",),
     ) -> Iterable[dict[str, Any]]:
         """
         Yield similarity metric dictionaries for all combinations of
@@ -218,7 +218,7 @@ class NXOntology(Freezable, Generic[Node]):
 
     @cache_on_frozen
     def _get_name_to_node_info(self) -> dict[str, Node_Info[Node]]:
-        name_to_node_info: dict[str, Node_Info[Node]] = dict()
+        name_to_node_info: dict[str, Node_Info[Node]] = {}
         for node in self.graph:
             info = self.node_info(node)
             name = info.name
