@@ -1,15 +1,18 @@
-from typing import Dict, Iterable, Optional
+from __future__ import annotations
+
+from typing import Iterable
 
 from networkx.drawing.nx_agraph import to_agraph
 from pygraphviz.agraph import AGraph
 
-from nxontology.ontology import Node, Node_Info, SimilarityIC
+from nxontology.node import Node, Node_Info
+from nxontology.similarity import SimilarityIC
 
 
 def create_similarity_graphviz(
     sim: SimilarityIC[Node],
-    nodes: Optional[Iterable[Node]] = None,
-) -> "AGraph":
+    nodes: Iterable[Node] | None = None,
+) -> AGraph:
     """
     Create a pygraphviz AGraph to render the similarity subgraph with graphviz.
     Works by creating a subgraph in networkx with the relevant nodes.
@@ -32,7 +35,7 @@ def create_similarity_graphviz(
         data["style"] = "filled"
         info = sim.nxo.node_info(node)
         data["label"] = (
-            f"<{info.label}<br/>"
+            f"<{info.name}<br/>"
             '<font point-size="9">'
             f"IC<sub>res</sub> {info.intrinsic_ic_scaled:.2f} · "
             f"IC<sub>sán</sub> {info.intrinsic_ic_sanchez_scaled:.2f}"
@@ -79,15 +82,15 @@ def create_similarity_graphviz(
 
 
 def get_verbose_node_label(info: Node_Info[Node]) -> str:
-    """Return verbose label like 'label (identifier)'."""
-    verbose_label = info.label
+    """Return verbose label like 'name (identifier)'."""
+    verbose_label = info.name
     assert isinstance(verbose_label, str)
     if info.identifier:
         verbose_label += f" ({info.identifier})"
     return verbose_label
 
 
-colormap: Dict[int, str] = {
+colormap: dict[int, str] = {
     0: "#f7fcf5",
     1: "#f6fcf4",
     2: "#f4fbf2",
